Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(214)

Unified Diff: chrome/browser/ui/ash/launcher/chrome_launcher_controller.h

Issue 11451019: Remove TabContents from ui/ash. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: fix Created 8 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/ash/launcher/chrome_launcher_controller.h
diff --git a/chrome/browser/ui/ash/launcher/chrome_launcher_controller.h b/chrome/browser/ui/ash/launcher/chrome_launcher_controller.h
index 2c605f3ae64637fd0856d9aec2208e2913ee6e02..fea1cb30720b88b6aa2fcc0f466d0e39b5ce4111 100644
--- a/chrome/browser/ui/ash/launcher/chrome_launcher_controller.h
+++ b/chrome/browser/ui/ash/launcher/chrome_launcher_controller.h
@@ -15,7 +15,6 @@
class BrowserLauncherItemControllerTest;
class LauncherItemController;
class Profile;
-class TabContents;
namespace ash {
class LauncherModel;
@@ -49,7 +48,7 @@ class ChromeLauncherController
STATE_NOT_INCOGNITO,
};
// Used to update the state of non plaform apps, as tab contents change.
enum AppState {
APP_STATE_ACTIVE,
APP_STATE_WINDOW_ACTIVE,
@@ -230,7 +229,7 @@ class ChromeLauncherController
virtual void ToggleShelfAutoHideBehavior(aura::RootWindow* root_window) = 0;
// The tab no longer represents its previously identified application.
- virtual void RemoveTabFromRunningApp(TabContents* tab,
+ virtual void RemoveTabFromRunningApp(content::WebContents* tab,
const std::string& app_id) = 0;
// Notify the controller that the state of an non platform app's tabs
@@ -49,7 +48,7 @@ class ChromeLauncherController
STATE_NOT_INCOGNITO,
};
- // Used to update the state of non plaform apps, as tab contents change.
+ // Used to update the state of non plaform apps, as web contents change.
enum AppState {
APP_STATE_ACTIVE,

Powered by Google App Engine
This is Rietveld 408576698